// Generated by delombok at Wed Mar 13 20:31:42 UTC 2024
package gov.cms.fiss.pricers.hha.api.v2;

import gov.cms.fiss.pricers.common.api.ClaimData;
import gov.cms.fiss.pricers.common.api.serialization.BigDecimalScale;
import gov.cms.fiss.pricers.common.api.serialization.StrictLocalDate;
import gov.cms.fiss.pricers.common.api.validation.ValidDecimalOutputWithTwoFractionDigits;
import io.swagger.v3.oas.annotations.extensions.Extension;
import io.swagger.v3.oas.annotations.extensions.ExtensionProperty;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Schema;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

@Schema(description = "The claim data.", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-INPUT-DATA", value = "<structure>")})})
public class HhaClaimData extends ClaimData {
  @Pattern(regexp = "\\d", message = "must be one digit")
  @Schema(description = "The adjustment indicator.", example = "2", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-ADJ-IND", value = "PIC X")})})
  private String adjustmentIndicator;
  @NotNull
  @Schema(description = "The date of the first service delivered by the HHA in an episode or a series of " + "continuous episodes.", example = "2021-06-19", format = "yyyy-MM-dd", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-ADMIT-DATE", value = "HHA-ADMIT-CC  PIC XX\n" + "HHA-ADMIT-YY  PIC XX\n" + "HHA-ADMIT-MM  PIC XX\n" + "HHA-ADMIT-DD  PIC XX")})})
  @StrictLocalDate
  private LocalDate admissionDate;
  @NotNull
  @Pattern(regexp = "[A-Z\\d]{5}", message = "must be five alphanumeric characters")
  @Schema(description = "The home health resource group (HHRG) input code.", example = "1FC11", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-HRG-INPUT-CODE", value = "PIC X(05)")})})
  private String hhrgInputCode;
  @Max(999)
  @Min(0)
  @NotNull
  @Schema(description = "The span of days between the first and last line item service dates.", example = "30", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-HRG-NO-OF-DAYS", value = "PIC 9(03)")})})
  private Integer hhrgNumberOfDays;
  @NotNull
  @Pattern(regexp = "\\d", message = "must be one digit")
  @Schema(description = "The initial payment quality reporting program (QRP) indicator.", example = "1", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-INIT-PAY-QRP-IND", value = "PIC X(01)")})})
  private String initialPaymentQualityReportingProgramIndicator;
  @Pattern(regexp = "[A-Z\\d]", message = "must be alphanumeric")
  @Schema(description = "The indicator that the late filing penalty has been waived.", example = "1", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-OVERRIDE-IND", value = "PIC X(01)")})})
  private String lateFilingPenaltyWaiverIndicator;
  @Pattern(regexp = "[A-Z\\d]", message = "must be one alphanumeric character")
  @Schema(description = "The low-utilization payment adjustment (LUPA) source admission indicator.", example = "B", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-LUPA-SRC-ADM", value = "PIC X")})})
  private String lupaSourceAdmissionIndicator;
  @Schema(description = "The receipt date of the corresponding request for anticipated payment (RAP) for this " + "claim.", example = "2021-10-12", format = "yyyy-MM-dd", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-RECEIPT-DATE", value = "PIC X(08)")})})
  @StrictLocalDate
  private LocalDate noticeReceiptDate;
  @Pattern(regexp = "[A-Z\\d]", message = "must be alphanumeric")
  @Schema(description = "The partial episode payment (PEP) indicator.", example = "1", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-PEP-IND", value = "PIC X")})})
  private String partialEpisodePaymentIndicator;
  @BigDecimalScale
  @NotNull
  @Schema(description = "The total amount of outlier payments that have been made for episodes ending during " + "the current calendar year.", example = "66003.39", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-PROV-OUTLIER-PAY-TOTAL", value = "PIC 9(09)V9(02)")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal priorOutlierTotal;
  @BigDecimalScale
  @NotNull
  @Schema(description = "The total amount of Home Health PPS payments that have been made for episodes ending " + "during the current calendar year.", example = "88350.20", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-PROV-PAYMENT-TOTAL", value = "PIC 9(09)V9(02)")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal priorPaymentTotal;
  @ArraySchema(arraySchema = @Schema(description = "The revenue data associated with this claim.", example = "[{\"revenueCode\":\"0420\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}," + "{\"revenueCode\":\"0430\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}," + "{\"revenueCode\":\"0440\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}," + "{\"revenueCode\":\"0550\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}," + "{\"revenueCode\":\"0560\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}," + "{\"revenueCode\":\"0570\",\"quantityOfCoveredVisits\":8," + "\"quantityOfOutlierUnits\":32,\"earliestLineItemDate\":\"2020-05-14\"}]"), uniqueItems = true, extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-REVENUE-DATA", value = "<structure>")})})
  @NotNull
  @Size(max = 6, min = 6)
  @Valid
  private List<@NotNull RevenueLineData> revenueLines;
  @NotNull
  @Schema(description = "The start date of service.", example = "2021-06-19", format = "yyyy-MM-dd", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-SERV-FROM-DATE", value = "HHA-FROM-CC  PIC XX\n" + "HHA-FROM-YY  PIC XX\n" + "HHA-FROM-MM  PIC XX\n" + "HHA-FROM-DD  PIC XX")})})
  @StrictLocalDate
  private LocalDate serviceFromDate;
  @NotNull
  @Schema(description = "The end date of service.", example = "2021-09-26", format = "yyyy-MM-dd", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-SERV-THRU-DATE", value = "HHA-THRU-CC  PIC XX\n" + "HHA-THRU-YY  PIC XX\n" + "HHA-THRU-MM  PIC XX\n" + "HHA-THRU-DD  PIC XX")})})
  @StrictLocalDate
  private LocalDate serviceThroughDate;
  @Pattern(regexp = "\\d{2}[A-Z0-9]", message = "must be two digits followed by an alphanumeric character")
  @Schema(description = "The type of bill.", example = "329", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-TOB", value = "PIC X(03)")})})
  private String typeOfBill;

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getAdjustmentIndicator() {
    return this.adjustmentIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public LocalDate getAdmissionDate() {
    return this.admissionDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getHhrgInputCode() {
    return this.hhrgInputCode;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public Integer getHhrgNumberOfDays() {
    return this.hhrgNumberOfDays;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getInitialPaymentQualityReportingProgramIndicator() {
    return this.initialPaymentQualityReportingProgramIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getLateFilingPenaltyWaiverIndicator() {
    return this.lateFilingPenaltyWaiverIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getLupaSourceAdmissionIndicator() {
    return this.lupaSourceAdmissionIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public LocalDate getNoticeReceiptDate() {
    return this.noticeReceiptDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getPartialEpisodePaymentIndicator() {
    return this.partialEpisodePaymentIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getPriorOutlierTotal() {
    return this.priorOutlierTotal;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getPriorPaymentTotal() {
    return this.priorPaymentTotal;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public List<@NotNull RevenueLineData> getRevenueLines() {
    return this.revenueLines;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public LocalDate getServiceFromDate() {
    return this.serviceFromDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public LocalDate getServiceThroughDate() {
    return this.serviceThroughDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public String getTypeOfBill() {
    return this.typeOfBill;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setAdjustmentIndicator(final String adjustmentIndicator) {
    this.adjustmentIndicator = adjustmentIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setAdmissionDate(final LocalDate admissionDate) {
    this.admissionDate = admissionDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setHhrgInputCode(final String hhrgInputCode) {
    this.hhrgInputCode = hhrgInputCode;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setHhrgNumberOfDays(final Integer hhrgNumberOfDays) {
    this.hhrgNumberOfDays = hhrgNumberOfDays;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setInitialPaymentQualityReportingProgramIndicator(final String initialPaymentQualityReportingProgramIndicator) {
    this.initialPaymentQualityReportingProgramIndicator = initialPaymentQualityReportingProgramIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setLateFilingPenaltyWaiverIndicator(final String lateFilingPenaltyWaiverIndicator) {
    this.lateFilingPenaltyWaiverIndicator = lateFilingPenaltyWaiverIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setLupaSourceAdmissionIndicator(final String lupaSourceAdmissionIndicator) {
    this.lupaSourceAdmissionIndicator = lupaSourceAdmissionIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setNoticeReceiptDate(final LocalDate noticeReceiptDate) {
    this.noticeReceiptDate = noticeReceiptDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setPartialEpisodePaymentIndicator(final String partialEpisodePaymentIndicator) {
    this.partialEpisodePaymentIndicator = partialEpisodePaymentIndicator;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setPriorOutlierTotal(final BigDecimal priorOutlierTotal) {
    this.priorOutlierTotal = priorOutlierTotal;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setPriorPaymentTotal(final BigDecimal priorPaymentTotal) {
    this.priorPaymentTotal = priorPaymentTotal;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setRevenueLines(final List<@NotNull RevenueLineData> revenueLines) {
    this.revenueLines = revenueLines;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setServiceFromDate(final LocalDate serviceFromDate) {
    this.serviceFromDate = serviceFromDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setServiceThroughDate(final LocalDate serviceThroughDate) {
    this.serviceThroughDate = serviceThroughDate;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setTypeOfBill(final String typeOfBill) {
    this.typeOfBill = typeOfBill;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public boolean equals(final java.lang.Object o) {
    if (o == this) return true;
    if (!(o instanceof HhaClaimData)) return false;
    final HhaClaimData other = (HhaClaimData) o;
    if (!other.canEqual((java.lang.Object) this)) return false;
    if (!super.equals(o)) return false;
    final java.lang.Object this$hhrgNumberOfDays = this.getHhrgNumberOfDays();
    final java.lang.Object other$hhrgNumberOfDays = other.getHhrgNumberOfDays();
    if (this$hhrgNumberOfDays == null ? other$hhrgNumberOfDays != null : !this$hhrgNumberOfDays.equals(other$hhrgNumberOfDays)) return false;
    final java.lang.Object this$adjustmentIndicator = this.getAdjustmentIndicator();
    final java.lang.Object other$adjustmentIndicator = other.getAdjustmentIndicator();
    if (this$adjustmentIndicator == null ? other$adjustmentIndicator != null : !this$adjustmentIndicator.equals(other$adjustmentIndicator)) return false;
    final java.lang.Object this$admissionDate = this.getAdmissionDate();
    final java.lang.Object other$admissionDate = other.getAdmissionDate();
    if (this$admissionDate == null ? other$admissionDate != null : !this$admissionDate.equals(other$admissionDate)) return false;
    final java.lang.Object this$hhrgInputCode = this.getHhrgInputCode();
    final java.lang.Object other$hhrgInputCode = other.getHhrgInputCode();
    if (this$hhrgInputCode == null ? other$hhrgInputCode != null : !this$hhrgInputCode.equals(other$hhrgInputCode)) return false;
    final java.lang.Object this$initialPaymentQualityReportingProgramIndicator = this.getInitialPaymentQualityReportingProgramIndicator();
    final java.lang.Object other$initialPaymentQualityReportingProgramIndicator = other.getInitialPaymentQualityReportingProgramIndicator();
    if (this$initialPaymentQualityReportingProgramIndicator == null ? other$initialPaymentQualityReportingProgramIndicator != null : !this$initialPaymentQualityReportingProgramIndicator.equals(other$initialPaymentQualityReportingProgramIndicator)) return false;
    final java.lang.Object this$lateFilingPenaltyWaiverIndicator = this.getLateFilingPenaltyWaiverIndicator();
    final java.lang.Object other$lateFilingPenaltyWaiverIndicator = other.getLateFilingPenaltyWaiverIndicator();
    if (this$lateFilingPenaltyWaiverIndicator == null ? other$lateFilingPenaltyWaiverIndicator != null : !this$lateFilingPenaltyWaiverIndicator.equals(other$lateFilingPenaltyWaiverIndicator)) return false;
    final java.lang.Object this$lupaSourceAdmissionIndicator = this.getLupaSourceAdmissionIndicator();
    final java.lang.Object other$lupaSourceAdmissionIndicator = other.getLupaSourceAdmissionIndicator();
    if (this$lupaSourceAdmissionIndicator == null ? other$lupaSourceAdmissionIndicator != null : !this$lupaSourceAdmissionIndicator.equals(other$lupaSourceAdmissionIndicator)) return false;
    final java.lang.Object this$noticeReceiptDate = this.getNoticeReceiptDate();
    final java.lang.Object other$noticeReceiptDate = other.getNoticeReceiptDate();
    if (this$noticeReceiptDate == null ? other$noticeReceiptDate != null : !this$noticeReceiptDate.equals(other$noticeReceiptDate)) return false;
    final java.lang.Object this$partialEpisodePaymentIndicator = this.getPartialEpisodePaymentIndicator();
    final java.lang.Object other$partialEpisodePaymentIndicator = other.getPartialEpisodePaymentIndicator();
    if (this$partialEpisodePaymentIndicator == null ? other$partialEpisodePaymentIndicator != null : !this$partialEpisodePaymentIndicator.equals(other$partialEpisodePaymentIndicator)) return false;
    final java.lang.Object this$priorOutlierTotal = this.getPriorOutlierTotal();
    final java.lang.Object other$priorOutlierTotal = other.getPriorOutlierTotal();
    if (this$priorOutlierTotal == null ? other$priorOutlierTotal != null : !this$priorOutlierTotal.equals(other$priorOutlierTotal)) return false;
    final java.lang.Object this$priorPaymentTotal = this.getPriorPaymentTotal();
    final java.lang.Object other$priorPaymentTotal = other.getPriorPaymentTotal();
    if (this$priorPaymentTotal == null ? other$priorPaymentTotal != null : !this$priorPaymentTotal.equals(other$priorPaymentTotal)) return false;
    final java.lang.Object this$revenueLines = this.getRevenueLines();
    final java.lang.Object other$revenueLines = other.getRevenueLines();
    if (this$revenueLines == null ? other$revenueLines != null : !this$revenueLines.equals(other$revenueLines)) return false;
    final java.lang.Object this$serviceFromDate = this.getServiceFromDate();
    final java.lang.Object other$serviceFromDate = other.getServiceFromDate();
    if (this$serviceFromDate == null ? other$serviceFromDate != null : !this$serviceFromDate.equals(other$serviceFromDate)) return false;
    final java.lang.Object this$serviceThroughDate = this.getServiceThroughDate();
    final java.lang.Object other$serviceThroughDate = other.getServiceThroughDate();
    if (this$serviceThroughDate == null ? other$serviceThroughDate != null : !this$serviceThroughDate.equals(other$serviceThroughDate)) return false;
    final java.lang.Object this$typeOfBill = this.getTypeOfBill();
    final java.lang.Object other$typeOfBill = other.getTypeOfBill();
    if (this$typeOfBill == null ? other$typeOfBill != null : !this$typeOfBill.equals(other$typeOfBill)) return false;
    return true;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  protected boolean canEqual(final java.lang.Object other) {
    return other instanceof HhaClaimData;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public int hashCode() {
    final int PRIME = 59;
    int result = super.hashCode();
    final java.lang.Object $hhrgNumberOfDays = this.getHhrgNumberOfDays();
    result = result * PRIME + ($hhrgNumberOfDays == null ? 43 : $hhrgNumberOfDays.hashCode());
    final java.lang.Object $adjustmentIndicator = this.getAdjustmentIndicator();
    result = result * PRIME + ($adjustmentIndicator == null ? 43 : $adjustmentIndicator.hashCode());
    final java.lang.Object $admissionDate = this.getAdmissionDate();
    result = result * PRIME + ($admissionDate == null ? 43 : $admissionDate.hashCode());
    final java.lang.Object $hhrgInputCode = this.getHhrgInputCode();
    result = result * PRIME + ($hhrgInputCode == null ? 43 : $hhrgInputCode.hashCode());
    final java.lang.Object $initialPaymentQualityReportingProgramIndicator = this.getInitialPaymentQualityReportingProgramIndicator();
    result = result * PRIME + ($initialPaymentQualityReportingProgramIndicator == null ? 43 : $initialPaymentQualityReportingProgramIndicator.hashCode());
    final java.lang.Object $lateFilingPenaltyWaiverIndicator = this.getLateFilingPenaltyWaiverIndicator();
    result = result * PRIME + ($lateFilingPenaltyWaiverIndicator == null ? 43 : $lateFilingPenaltyWaiverIndicator.hashCode());
    final java.lang.Object $lupaSourceAdmissionIndicator = this.getLupaSourceAdmissionIndicator();
    result = result * PRIME + ($lupaSourceAdmissionIndicator == null ? 43 : $lupaSourceAdmissionIndicator.hashCode());
    final java.lang.Object $noticeReceiptDate = this.getNoticeReceiptDate();
    result = result * PRIME + ($noticeReceiptDate == null ? 43 : $noticeReceiptDate.hashCode());
    final java.lang.Object $partialEpisodePaymentIndicator = this.getPartialEpisodePaymentIndicator();
    result = result * PRIME + ($partialEpisodePaymentIndicator == null ? 43 : $partialEpisodePaymentIndicator.hashCode());
    final java.lang.Object $priorOutlierTotal = this.getPriorOutlierTotal();
    result = result * PRIME + ($priorOutlierTotal == null ? 43 : $priorOutlierTotal.hashCode());
    final java.lang.Object $priorPaymentTotal = this.getPriorPaymentTotal();
    result = result * PRIME + ($priorPaymentTotal == null ? 43 : $priorPaymentTotal.hashCode());
    final java.lang.Object $revenueLines = this.getRevenueLines();
    result = result * PRIME + ($revenueLines == null ? 43 : $revenueLines.hashCode());
    final java.lang.Object $serviceFromDate = this.getServiceFromDate();
    result = result * PRIME + ($serviceFromDate == null ? 43 : $serviceFromDate.hashCode());
    final java.lang.Object $serviceThroughDate = this.getServiceThroughDate();
    result = result * PRIME + ($serviceThroughDate == null ? 43 : $serviceThroughDate.hashCode());
    final java.lang.Object $typeOfBill = this.getTypeOfBill();
    result = result * PRIME + ($typeOfBill == null ? 43 : $typeOfBill.hashCode());
    return result;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public java.lang.String toString() {
    return "HhaClaimData(adjustmentIndicator=" + this.getAdjustmentIndicator() + ", admissionDate=" + this.getAdmissionDate() + ", hhrgInputCode=" + this.getHhrgInputCode() + ", hhrgNumberOfDays=" + this.getHhrgNumberOfDays() + ", initialPaymentQualityReportingProgramIndicator=" + this.getInitialPaymentQualityReportingProgramIndicator() + ", lateFilingPenaltyWaiverIndicator=" + this.getLateFilingPenaltyWaiverIndicator() + ", lupaSourceAdmissionIndicator=" + this.getLupaSourceAdmissionIndicator() + ", noticeReceiptDate=" + this.getNoticeReceiptDate() + ", partialEpisodePaymentIndicator=" + this.getPartialEpisodePaymentIndicator() + ", priorOutlierTotal=" + this.getPriorOutlierTotal() + ", priorPaymentTotal=" + this.getPriorPaymentTotal() + ", revenueLines=" + this.getRevenueLines() + ", serviceFromDate=" + this.getServiceFromDate() + ", serviceThroughDate=" + this.getServiceThroughDate() + ", typeOfBill=" + this.getTypeOfBill() + ")";
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public HhaClaimData() {
  }
}
