// Generated by delombok at Wed Mar 13 20:31:42 UTC 2024
package gov.cms.fiss.pricers.hha.api.v2;

import gov.cms.fiss.pricers.common.api.PaymentData;
import gov.cms.fiss.pricers.common.api.annotations.FixedValue;
import gov.cms.fiss.pricers.common.api.serialization.BigDecimalScale;
import gov.cms.fiss.pricers.common.api.validation.ValidDecimalOutputWithTwoFractionDigits;
import gov.cms.fiss.pricers.common.util.BigDecimalUtils;
import io.swagger.v3.oas.annotations.extensions.Extension;
import io.swagger.v3.oas.annotations.extensions.ExtensionProperty;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Schema;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.Digits;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

@Schema(description = "The HHA prospective payment data.", extensions = @Extension(name = "cobol-declaration", properties = @ExtensionProperty(name = "HHA-INPUT-DATA", value = "<structure>")))
public class HhaPaymentData extends PaymentData {
  @BigDecimalScale
  @NotNull
  @Schema(description = "The payment amount calculated by the Pricer for the Health Insurance " + "Prospective Payment System Code (HIPPS) code.", example = "2129.06", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-HRG-PAY", value = "PIC 9(09)V9(02)")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal hhrgPayment = BigDecimalUtils.ZERO;
  @BigDecimalScale(scale = 4)
  @DecimalMin("0")
  @DecimalMax("99.9999")
  @Digits(integer = 2, fraction = 4)
  @NotNull
  @Schema(description = "The weight used to determine the payment amount on the claim.", example = "12.5932", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-HRG-WGTS", value = "PIC 9(02)V9(04)")})})
  @FixedValue
  private BigDecimal hhrgWeight = BigDecimal.ZERO.setScale(4, RoundingMode.HALF_UP);
  @BigDecimalScale
  @Schema(description = "The late submission penalty amount.", example = "50.20", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-LATE-SUB-PEN-AMT", value = "PIC 9(9)V9(2)")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal lateSubmissionPenaltyAmount = BigDecimalUtils.ZERO;
  @BigDecimalScale
  @Schema(description = "The outlier payment amount in addition to any HRG payment amounts.", example = "3500.29", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-OUTLIER-PAYMENT", value = "PIC 9(09)V9(02)")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal outlierPayment = BigDecimalUtils.ZERO;
  @ArraySchema(arraySchema = @Schema(description = "The revenue data."), uniqueItems = true, extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-REVENUE-DATA", value = "<structure>")})})
  @NotNull
  @Size(max = 6, min = 6)
  @Valid
  private List<@NotNull RevenuePaymentData> revenuePayments;
  @BigDecimalScale
  @NotNull
  @Schema(description = "The Home Health PPS payment without applying any provider-specific adjustments.", example = "995.29", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-PPS-STD-VALUE", value = "PIC 9(9)V99")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal standardizedPayment = BigDecimalUtils.ZERO;
  @Max(99999)
  @Min(0)
  @NotNull
  @Schema(description = "The total number of visits used to determine if the claim must be paid as a " + "low-utilization payment adjustment (LUPA).", example = "9", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-REVENUE-SUM1-6-QTY-ALL", value = "PIC 9(05)")})})
  private int totalQuantityOfCoveredVisits;
  @BigDecimalScale
  @Schema(description = "The value-based purchasing (VBP) adjustment amount.", example = "152.99", extensions = {@Extension(name = "cobol-declaration", properties = {@ExtensionProperty(name = "HHA-VBP-ADJ-AMT", value = "PIC S9(9)V99")})})
  @ValidDecimalOutputWithTwoFractionDigits
  private BigDecimal valueBasedPurchasingAdjustmentAmount = BigDecimalUtils.ZERO;

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getHhrgPayment() {
    return this.hhrgPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getHhrgWeight() {
    return this.hhrgWeight;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getLateSubmissionPenaltyAmount() {
    return this.lateSubmissionPenaltyAmount;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getOutlierPayment() {
    return this.outlierPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public List<@NotNull RevenuePaymentData> getRevenuePayments() {
    return this.revenuePayments;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getStandardizedPayment() {
    return this.standardizedPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public int getTotalQuantityOfCoveredVisits() {
    return this.totalQuantityOfCoveredVisits;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public BigDecimal getValueBasedPurchasingAdjustmentAmount() {
    return this.valueBasedPurchasingAdjustmentAmount;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setHhrgPayment(final BigDecimal hhrgPayment) {
    this.hhrgPayment = hhrgPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setHhrgWeight(final BigDecimal hhrgWeight) {
    this.hhrgWeight = hhrgWeight;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setLateSubmissionPenaltyAmount(final BigDecimal lateSubmissionPenaltyAmount) {
    this.lateSubmissionPenaltyAmount = lateSubmissionPenaltyAmount;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setOutlierPayment(final BigDecimal outlierPayment) {
    this.outlierPayment = outlierPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setRevenuePayments(final List<@NotNull RevenuePaymentData> revenuePayments) {
    this.revenuePayments = revenuePayments;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setStandardizedPayment(final BigDecimal standardizedPayment) {
    this.standardizedPayment = standardizedPayment;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setTotalQuantityOfCoveredVisits(final int totalQuantityOfCoveredVisits) {
    this.totalQuantityOfCoveredVisits = totalQuantityOfCoveredVisits;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public void setValueBasedPurchasingAdjustmentAmount(final BigDecimal valueBasedPurchasingAdjustmentAmount) {
    this.valueBasedPurchasingAdjustmentAmount = valueBasedPurchasingAdjustmentAmount;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public boolean equals(final java.lang.Object o) {
    if (o == this) return true;
    if (!(o instanceof HhaPaymentData)) return false;
    final HhaPaymentData other = (HhaPaymentData) o;
    if (!other.canEqual((java.lang.Object) this)) return false;
    if (!super.equals(o)) return false;
    if (this.getTotalQuantityOfCoveredVisits() != other.getTotalQuantityOfCoveredVisits()) return false;
    final java.lang.Object this$hhrgPayment = this.getHhrgPayment();
    final java.lang.Object other$hhrgPayment = other.getHhrgPayment();
    if (this$hhrgPayment == null ? other$hhrgPayment != null : !this$hhrgPayment.equals(other$hhrgPayment)) return false;
    final java.lang.Object this$hhrgWeight = this.getHhrgWeight();
    final java.lang.Object other$hhrgWeight = other.getHhrgWeight();
    if (this$hhrgWeight == null ? other$hhrgWeight != null : !this$hhrgWeight.equals(other$hhrgWeight)) return false;
    final java.lang.Object this$lateSubmissionPenaltyAmount = this.getLateSubmissionPenaltyAmount();
    final java.lang.Object other$lateSubmissionPenaltyAmount = other.getLateSubmissionPenaltyAmount();
    if (this$lateSubmissionPenaltyAmount == null ? other$lateSubmissionPenaltyAmount != null : !this$lateSubmissionPenaltyAmount.equals(other$lateSubmissionPenaltyAmount)) return false;
    final java.lang.Object this$outlierPayment = this.getOutlierPayment();
    final java.lang.Object other$outlierPayment = other.getOutlierPayment();
    if (this$outlierPayment == null ? other$outlierPayment != null : !this$outlierPayment.equals(other$outlierPayment)) return false;
    final java.lang.Object this$revenuePayments = this.getRevenuePayments();
    final java.lang.Object other$revenuePayments = other.getRevenuePayments();
    if (this$revenuePayments == null ? other$revenuePayments != null : !this$revenuePayments.equals(other$revenuePayments)) return false;
    final java.lang.Object this$standardizedPayment = this.getStandardizedPayment();
    final java.lang.Object other$standardizedPayment = other.getStandardizedPayment();
    if (this$standardizedPayment == null ? other$standardizedPayment != null : !this$standardizedPayment.equals(other$standardizedPayment)) return false;
    final java.lang.Object this$valueBasedPurchasingAdjustmentAmount = this.getValueBasedPurchasingAdjustmentAmount();
    final java.lang.Object other$valueBasedPurchasingAdjustmentAmount = other.getValueBasedPurchasingAdjustmentAmount();
    if (this$valueBasedPurchasingAdjustmentAmount == null ? other$valueBasedPurchasingAdjustmentAmount != null : !this$valueBasedPurchasingAdjustmentAmount.equals(other$valueBasedPurchasingAdjustmentAmount)) return false;
    return true;
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  protected boolean canEqual(final java.lang.Object other) {
    return other instanceof HhaPaymentData;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public int hashCode() {
    final int PRIME = 59;
    int result = super.hashCode();
    result = result * PRIME + this.getTotalQuantityOfCoveredVisits();
    final java.lang.Object $hhrgPayment = this.getHhrgPayment();
    result = result * PRIME + ($hhrgPayment == null ? 43 : $hhrgPayment.hashCode());
    final java.lang.Object $hhrgWeight = this.getHhrgWeight();
    result = result * PRIME + ($hhrgWeight == null ? 43 : $hhrgWeight.hashCode());
    final java.lang.Object $lateSubmissionPenaltyAmount = this.getLateSubmissionPenaltyAmount();
    result = result * PRIME + ($lateSubmissionPenaltyAmount == null ? 43 : $lateSubmissionPenaltyAmount.hashCode());
    final java.lang.Object $outlierPayment = this.getOutlierPayment();
    result = result * PRIME + ($outlierPayment == null ? 43 : $outlierPayment.hashCode());
    final java.lang.Object $revenuePayments = this.getRevenuePayments();
    result = result * PRIME + ($revenuePayments == null ? 43 : $revenuePayments.hashCode());
    final java.lang.Object $standardizedPayment = this.getStandardizedPayment();
    result = result * PRIME + ($standardizedPayment == null ? 43 : $standardizedPayment.hashCode());
    final java.lang.Object $valueBasedPurchasingAdjustmentAmount = this.getValueBasedPurchasingAdjustmentAmount();
    result = result * PRIME + ($valueBasedPurchasingAdjustmentAmount == null ? 43 : $valueBasedPurchasingAdjustmentAmount.hashCode());
    return result;
  }

  @java.lang.Override
  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public java.lang.String toString() {
    return "HhaPaymentData(hhrgPayment=" + this.getHhrgPayment() + ", hhrgWeight=" + this.getHhrgWeight() + ", lateSubmissionPenaltyAmount=" + this.getLateSubmissionPenaltyAmount() + ", outlierPayment=" + this.getOutlierPayment() + ", revenuePayments=" + this.getRevenuePayments() + ", standardizedPayment=" + this.getStandardizedPayment() + ", totalQuantityOfCoveredVisits=" + this.getTotalQuantityOfCoveredVisits() + ", valueBasedPurchasingAdjustmentAmount=" + this.getValueBasedPurchasingAdjustmentAmount() + ")";
  }

  @java.lang.SuppressWarnings("all")
  @lombok.Generated
  public HhaPaymentData() {
  }
}
